Date: 08 27, 2001 10:11:21 AM

# VisualText Quick Tour

Welcome to the VisualText™ Quick Tour, which introduces the major components of VisualText and shows how these components work together to create, run, and debug a text analyzer.

The Quick Tour walks you through a working analyzer called the Corporate Analyzer. The Corporate Analyzer demonstrates the features of VisualText and introduces you to building analyzers using VisualText. It is intended as a demonstration analyzer only and is meant to be used with the sample input files provided.

In addition to the Quick Tour, we have provided a more detailed tour of the Corporate Analyzer in the Sample Analyzers "section" (or "folder" in the Help). The full tour takes you through the step-by-step process used in building the Corporate Analyzer.

We recommend that you run the Corporate Analyzer application as you go through both the Quick Tour and the more detailed Corporate Analyzer tour. The Corporate Analyzer application is located in the APPS folder under your VisualText installation directory, in a folder named corporate.

To run the analyzer, follow the steps outlined below:

1. Launch VisualText.

2. From the File menu, select Open Analyzer.

3. In the Open dialog, navigate to the top level corporate folder (c:\Program Files\TextAI\VisualText\apps\corporate, by default.)

4. Select the corporate.ana file and click Open.

Start the Quick Tour.